@@ -16,7 +16,7 @@ our @EXPORT_OK = ( @{ $EXPORT_TAGS{'all'} } );
 our @EXPORT = qw(
 	
 );
-our $VERSION = '0.5';
+our $VERSION = '0.6';
 our $EVENT_NONE = 0;
 our $EVENT_MSG = 1;
 our $EVENT_NOTIFY = 2;
@@ -46,10 +46,15 @@ sub set_server {
 
 sub search {
     my ($cl,$nickname,$first_name,$last_name,$city,$gender,$active) = @_;
-    my %gd = ("male" => 2, "famale" => 1, "none" => 0);
+    my %gd = ("male" => 2, "female" => 1, "none" => 0);
     return Net::Gadu::gg_search($nickname,$first_name,$last_name,$city,$gd{$gender},$active);
 }
 
+sub search_uin {
+    my ($cl,$uin,$active) = @_;
+    return Net::Gadu::gg_search_uin($uin,$active);
+}
+
 sub login {
     my ($cl,$uin,$password) = @_;
     $cl->{uin}=$uin;
@@ -128,13 +133,13 @@ Net::Gadu - Interfejs do biblioteki libgadu.so (czesc ekg)
 
 Bardzo wstepna i testowa wersja modulu, ale chyba dziala.
 
-Wykozystuje biblioteke libgadu.so ktora jest czescia projektu Ekg ( http://dev.null.pl/ekg/ )
+Wykorzystuje biblioteke libgadu.so ktora jest czescia projektu Ekg ( http://dev.null.pl/ekg/ )
 Aby ja otrzymac nalezy skompilowac ekg z opcja --with-shared. Jesli uzywasz ekg z pakietu prawdopodobnie
 biblioteka ta jest automatycznie instalowana w systemie.
 
 =head1 DOWNLOAD
 
-http://krzak.linux.net.pl/perl/Net-Gadu-0.5.tar.gz
+http://krzak.linux.net.pl/perl/Net-Gadu-0.6.tar.gz
 
 =head1 METHODS
 
@@ -169,34 +174,39 @@ Ustawia status na dostepny, podobne funkcje : set_busy(), set_invisible(), set_n
 
 =item $gg->search($nickname,$first_name,$last_name,$city,$gender,$active)
 
-    $gender = "male" lub "famale" lub "none")
+    $gender = "male" lub "female" lub "none")
     $active = 1 lub 0
 
+=item $gg->search_uin($uin,$active)
+    
+    szuka uzytkownika o podanym UIN 
+    (active oznacza czy ma szukac posrod aktywnych czy nie)
+
 =item $gg->check_event()
 
     Sprawdza czy zaszlo jakies zdarzenie (przydatne przy polaczeniu asynchronicznym zwlaszcza)
     
 =item $gg->get_event()
 
-    Zwraca dane ze zdarzenia ktore zaszlo, zwracana jest tablica haszy np :
+    Zwraca dane ze zdarzenia ktore zaszlo, zwracany jest hasz np :
 	$e = $gg_event();
 	
-    $e->[0]->{type} zawiera kod ostatniego zdarzenia
+    $e->{type} zawiera kod ostatniego zdarzenia
     
 	$Net::Gadu::EVENT_MSG
-	        $e->[0]->{message}  # tresc wiadomosci
-		$e->[0]->{sender}   # uin wysylajacego
-		$e->[0]->{msgclass}    # typ wiadomosci
+	        $e->{message}  # tresc wiadomosci
+		$e->{sender}   # uin wysylajacego
+		$e->{msgclass}    # typ wiadomosci
 
 	$Net::Gadu::EVENT_ACK	    # potwierdzenie wyslania wiadomosci
-	        $e->[0]->{recipient}
-		$e->[0]->{status}
-		$e->[0]->{seq}
+	        $e->{recipient}
+		$e->{status}
+		$e->{seq}
 
 	$Net::Gadu::EVENT_STATUS    # zmiana statusu
-	        $e->[0]->{uin}
-		$e->[0]->{status}
-		$e->[0]->{descr}
+	        $e->{uin}
+		$e->{status}
+		$e->{descr}
 
     Dostepne kody zdarzen :
     
@@ -226,9 +236,9 @@ Ustawia status na dostepny, podobne funkcje : set_busy(), set_invisible(), set_n
     my $gg = new Net::Gadu(async=>1);
 
     # SEARCH
-    my $res = $gg->search("","Ania","","","famale",0);
+    my $res = $gg->search("","Ania","","","female",0);
     foreach my $a (@{$res}) {
-        print $a->{nickname}." ".$a->{uin}." ".$a->{first_name}." ".$a->{last_name}." ".$a->{city}." ".$a->{born}."\n";
+        print $a->{nickname}." ".$a->{uin}." ".$a->{first_name}." ".$a->{last_name}." ".$a->{city}." ".$a->{born}." ".$a->{active}."\n";
     }
 
     #print ($res->[1]->{uin});
@@ -243,7 +253,7 @@ Ustawia status na dostepny, podobne funkcje : set_busy(), set_invisible(), set_n
 
 	my $e = $gg->get_event();
 
-	my $type = $e->[0]->{type};
+	my $type = $e->{type};
 	
 	if ($type == $Net::Gadu::EVENT_CONN_SUCCESS) {
 	    $gg->set_available();
@@ -251,7 +261,7 @@ Ustawia status na dostepny, podobne funkcje : set_busy(), set_invisible(), set_n
 	}
 
 	if ($type == $Net::Gadu::EVENT_MSG) {
-	    print $e->[0]->{message}." ".$e->[0]->{sender}."\n";
+	    print $e->{message}." ".$e->{sender}."\n";
 	}
 	
 
